@@ -71,21 +71,26 @@ over time.
 
 Consequently, one should not rely in the current API unless you are
 planning to keep track of the development of this module. It is still
-very much in flux, and may change without warning.
+very much in flux, and may change without warning. Just installing and
+using it as a Linked Data server should be OK, however, as its
+important functionality is unlikely to change in non-backwards
+compatible ways.
 
 
 =head1 METHODS
 
 =over
 
-=item C<< new ( store => $store, model => $model, base_uri => $base_uri, request => $request ) >>
+=item C<< new ( store => $store, model => $model, base_uri => $base_uri, 
+                request => $request, endpoint_config => $endpoint_config ) >>
 
 Creates a new handler object based on named parameters, given a store
 config (recommended usage is to pass a hashref of the type that can be
 passed to L<RDF::Trine::Store>->new_with_config, but a simple string
 can also be used) or model and a base URI. Optionally, you may pass a
-Apache request object, and you will need to pass a L<HTTP::Headers>
-object if you plan to call C<content>.
+L<Plack::Request> object (must be there if you if you plan to call
+C<content>) and an C<endpoint_config> hashref if you want to have a
+SPARQL Endpoint running using the recommended module L<RDF::Endpoint>.
 
 =cut
 
@@ -107,7 +112,7 @@ sub BUILD {
 
         throw Error -text => "No valid RDF::Trine::Model, need either a store config hashref or a model." unless ($self->model);
 
- 	if (defined($self->endpoint_config)) {
+ 	if ($self->has_endpoint_config) {
 	  use Data::Dumper;
 	  $self->logger->debug('Endpoint config found with parameters: ' . Dumper($self->endpoint_config) );
 
@@ -121,16 +126,26 @@ sub BUILD {
 	}
 }
 
-has endpoint_config => (is => 'ro');
-
-has endpoint => (is => 'rw', isa => 'RDF::Endpoint', default => undef );
-
 has store => (is => 'rw', isa => 'HashRef' );
 
+has endpoint_config => (is => 'ro', isa=>'HashRef', predicate => 'has_endpoint_config');
 
-=item C<< request ( [ $headers ] ) >>
+=item C<< endpoint ( [ $endpoint ] ) >>
 
-Returns the L<HTTP::Headers> object if it exists or sets it if a L<HTTP::Headers> object is given as parameter.
+Returns the L<RDF::Endpoint> object if it exists or sets it if a
+L<RDF::Endpoint> object is given as parameter. In most cases, it will
+be created for you if you pass a C<endpoint_config> hashref to the
+constructor, so you would most likely not use this method.
+
+=cut
+
+
+has endpoint => (is => 'rw', isa => 'RDF::Endpoint', predicate => 'has_endpoint');
+
+
+=item C<< request ( [ $request ] ) >>
+
+Returns the L<Plack::Request> object if it exists or sets it if a L<Plack::Request> object is given as parameter.
 
 =cut
 
@@ -293,11 +308,11 @@ sub response {
 
     my $headers_in = $self->request->headers;
     my $endpoint_path = '/sparql';
-    if (defined($self->endpoint_config) && defined($self->endpoint_config->{endpoint_path})) {
+    if ($self->has_endpoint_config && defined($self->endpoint_config->{endpoint_path})) {
       my $endpoint_path = $self->endpoint_config->{endpoint_path};
     }
 
-    if(defined($self->endpoint) && ($uri->path eq $endpoint_path)) {
+    if($self->has_endpoint && ($uri->path eq $endpoint_path)) {
       return $self->endpoint->run( $self->request );
     }
 
